@@ -5,7 +5,7 @@ string GPGMail::mailCommand(string const &recipient) const
     return
         "/usr/bin/mail -s '" + subject() + "' "
                 "-a \"Reply-To: " + d_replyTo + "\" " +
-                headers() + 
+                headers(&processHeaders) + 
                 " -a 'Content-Type: multipart/encrypted; "
                     R"(protocol="application/pgp-encrypted"; )"
                     R"(boundary=")" + d_boundary + R"("' )" +
